#!/bin/sh
echo 'name: cryptohash
version: 0.9.0
id: cryptohash-0.9.0-0f1b37dfae6666c203ab771afe9b14e5

license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability:
homepage: http://github.com/vincenthz/hs-cryptohash
package-url:
synopsis: collection of crypto hashes, fast, pure and practical
description: A collection of crypto hashes, with a practical incremental and one-pass, pure APIs,
             with performance close to the fastest implementations available in others languages.
             .
             The implementations are made in C with a haskell FFI wrapper that hide the C implementation.
             .
             Simple examples using the unified API:
             .
             > import Crypto.Hash
             >
             > sha1 :: ByteString -> Digest SHA1
             > sha1 = hash
             >
             > hexSha3_512 :: ByteString -> String
             > hexSha3_512 bs = show (hash bs :: Digest SHA3_512)
             .
             Simple examples using the module API:
             .
             > import qualified Crypto.Hash.SHA1 as SHA1
             >
             > main = putStrLn $ show $ SHA1.hash (Data.ByteString.pack [1..256])
             .
             > import qualified Crypto.Hash.SHA3 as SHA3
             >
             > main = putStrLn $ show $ digest
             >   where digest = SHA3.finalize ctx
             >         ctx    = foldl'\'' SHA3.update iCtx (map Data.ByteString.pack [ [1,2,3], [4,5,6] ]
             >         iCtx   = SHA3.init 224
category: Data, Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules: Crypto.Hash Crypto.Hash.Types Crypto.Hash.SHA1
                 Crypto.Hash.SHA224 Crypto.Hash.SHA256 Crypto.Hash.SHA384
                 Crypto.Hash.SHA512 Crypto.Hash.SHA512t Crypto.Hash.SHA3
                 Crypto.Hash.MD2 Crypto.Hash.MD4 Crypto.Hash.MD5
                 Crypto.Hash.RIPEMD160 Crypto.Hash.Skein256 Crypto.Hash.Skein512
                 Crypto.Hash.Tiger Crypto.Hash.Whirlpool Crypto.MAC.HMAC
hidden-modules: Crypto.Hash.Utils Crypto.Hash.Utils.Cpu
                Crypto.Hash.Internal
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/cryptohash-0.9.0
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/cryptohash-0.9.0
              /usr/local/lib
hs-libraries: HScryptohash-0.9.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.6.0.1-2324e29e8f7c561043683fccde7728aa
         bytestring-0.10.0.2-eecc198ed81abb69aaded5c195068445
         cereal-0.3.5.2-a8a790d0768a9248e2a627d1a1b5697e
         crypto-api-0.12.1-0c0239c96f8f18dad11c8e86469cfbf5
         ghc-prim-0.3.0.0-00db43fcd2f6e2a73243bdb496b765e0
         tagged-0.6-7d73f52235c53f67928eb3a120111ee7
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/cryptohash-0.9.0/html/cryptohash.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/cryptohash-0.9.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
